diff -Naur modules.orig/tv/classes/Schedule.php modules/tv/classes/Schedule.php
--- modules.orig/tv/classes/Schedule.php	2013-09-15 19:11:23.000000000 -0700
+++ modules/tv/classes/Schedule.php	2013-12-03 22:29:59.496596489 -0800
@@ -205,7 +205,7 @@
             }
         // Data is a recordid -- load its contents
             if (!is_array($data) && $data > 0) {
-                $data = $db->query_assoc('SELECT *, IF(type='.rectype_always.',-1,chanid)         AS chanid,
+                $data = $db->query_assoc('SELECT *, 
                                                  UNIX_TIMESTAMP(startdate)+TIME_TO_SEC(starttime) AS starttime,
                                                  UNIX_TIMESTAMP(enddate)+TIME_TO_SEC(endtime)     AS endtime
                                             FROM record
diff -Naur modules.orig/tv/tmpl/default/schedules.php modules/tv/tmpl/default/schedules.php
--- modules.orig/tv/tmpl/default/schedules.php	2013-09-15 19:11:23.000000000 -0700
+++ modules/tv/tmpl/default/schedules.php	2013-12-02 15:41:40.241817362 -0800
@@ -95,9 +95,11 @@
             $urlstr = 'recordid='.$schedule->recordid;
 
             $css_class = ($schedule->type == rectype_dontrec ? 'deactivated' : 'scheduled');
-        // If this is an 'always on any channel' or 'find one' recording w/o a channel, set the channel name to 'Any'
-            if ($schedule->type == rectype_always || ($schedule->type == rectype_findone && !preg_match('/\\S/', $schedule->channel->channum)))
+        // If this is an 'always on any channel' or 'find one' recording without the 'This Channel' filter, set the channel name to 'Any'
+            if (($schedule->type == rectype_always || $schedule->type == rectype_findone) && !($schedule->filter & (1 << 10))) {
                 $schedule->channel->name = '[ '.t('Any').' ]';
+                $schedule->channel->channum = 0;
+            }
         // A program id counter for popup info
             if ($_SESSION["show_popup_info"]) {
                 static $program_id_counter = 0;
diff -Naur modules.orig/tv/tmpl/lite/schedules.php modules/tv/tmpl/lite/schedules.php
--- modules.orig/tv/tmpl/lite/schedules.php	2013-09-15 19:11:23.000000000 -0700
+++ modules/tv/tmpl/lite/schedules.php	2013-12-03 22:18:59.324810621 -0800
@@ -53,9 +53,11 @@
             $urlstr = 'recordid='.$schedule->recordid;
 
             $css_class = ($schedule->type == rectype_dontrec ? 'deactivated' : 'scheduled');
-        // If this is an 'always on any channel' or 'find one' recording w/o a channel, set the channel name to 'Any'
-            if ($schedule->type == rectype_always || ($schedule->type == rectype_findone && !preg_match('/\\S/', $schedule->channel->channum)))
+        // If this is an 'always on any channel' or 'find one' recording without the 'This Channel' filter, set the channel name to 'Any'
+            if (($schedule->type == rectype_always || $schedule->type == rectype_findone) && !($schedule->filter & (1 << 10))) {
                 $schedule->channel->name = '[ '.t('Any').' ]';
+                $schedule->channel->channum = 0;
+            }
 
         // Print a dividing row if grouping changes
             if ($group_field == 'type')
